@@ -26,8 +26,6 @@ class Layer:
             raise ValueError('Activation should be among [sigmoid,tanh,relu]')
         else:
             self.activation = activation
-        self.derivatives = self.derivative()
-        self.fitted = self.fit()
     def __sigmoid(self,x:np.array)->np.array:
         """Sigmoid activation function for the neural network
         Calculates sigmoid value by using the formula sigmoid(z) = 1/(1+e^(-z))
@@ -48,13 +46,7 @@ class Layer:
         Returns:
             np.array: The array with ReLU function applied 
         """              
-        outputs = []
-        for element in x:
-            if element>0:
-                outputs.append(x)
-            else:
-                outputs.append(0)
-        return np.array(outputs)
+        return np.maximum(0,x)
     def derivative(self)->np.array:
         """Returns the differentiation of the activation function for a corresponding layer
 
@@ -67,7 +59,7 @@ class Layer:
         elif self.activation.strip().lower() == 'tanh':
             return 1-(a**2)
         elif self.activation.strip().lower() == 'relu':
-            return 1 if a>0 else 0
+            return np.array([1 if i>=0 else 0 for i in a.flatten()],dtype=float).reshape(a.shape)
 
     def fit(self)->np.array:
         """Fits the layer according to the formula a = activation_function(wx+b)
@@ -83,8 +75,6 @@ class Layer:
         elif self.activation.strip().lower() == 'relu':
             a = self.__relu(z)
         return a
-    def back_propagate(self,alpha=0.01):
-        self.weights -= alpha*self.derivatives
 class Network:
     def __init__(self,layers:list) -> None:
         """Initializes the neural network with the given layers
